@@ -6,6 +6,6 @@
   ob <- deparse(substitute(object) )
   val <- deparse( substitute( value ) )
   command <- paste( ob, "<-", ob, "+", val )
-  invisible( eval( parse( text = command ), env = parent.frame(1) ) )
+  invisible( eval( parse( text = command ), envir = parent.frame(1) ) )
 }
 
